@@ -1,7 +1,10 @@
-use std::{fmt, fmt::Display, io};
+use std::{fmt, io};
 
-use color_eyre::{eyre::{ensure, Context}, Result};
-use termion::{cursor, terminal_size};
+use crossterm::{
+    cursor,
+    terminal::{self, Clear, ClearType},
+};
+use eyre::{ensure, Context, Result};
 
 use super::{keyboard::Keyboard, state::State};
 
@@ -11,18 +14,18 @@ pub struct Game {
     keyboard: Keyboard,
 }
 
-impl Display for Game {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let (_width, height) = terminal_size().map_err(|_| std::fmt::Error)?;
+impl fmt::Display for Game {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        let (_width, height) = terminal::size().map_err(|_| fmt::Error)?;
 
         write!(
             f,
             "{clear_all}{bottom_left}Press ESC to exit.{top_left}Wordle {game_type}{down}{keyboard}{state}",
-            clear_all = termion::clear::All,
-            bottom_left = cursor::Goto(1, height),
-            top_left = cursor::Goto(1, 1),
+            clear_all = Clear(ClearType::All),
+            bottom_left = cursor::MoveTo(0, height-1),
+            top_left = cursor::MoveTo(0, 0),
             game_type = self.game_type,
-            down = cursor::Goto(1, 3),
+            down = cursor::MoveTo(0, 2),
             keyboard = self.keyboard,
             state = self.state
         )?;
@@ -52,7 +55,7 @@ impl Game {
         Self::new_raw(solution, GameType::Daily(day))
     }
 
-    fn new_raw(solution: String, game_type: GameType) -> color_eyre::Result<Self> {
+    fn new_raw(solution: String, game_type: GameType) -> Result<Self> {
         ensure!(
             cl_wordle::words::FINAL.contains(&&*solution),
             "{} is not a valid solution",
@@ -75,7 +78,7 @@ impl Game {
     }
 
     pub fn write_final_solution(&self, w: impl io::Write) -> io::Result<()> {
-        self.state.draw_final_solution(w)
+        self.state.write_final_solution(w)
     }
 
     pub fn display_share_card(&self, mut f: impl fmt::Write) -> fmt::Result {
@@ -97,8 +100,8 @@ pub enum GameType {
     Custom,
 }
 
-impl Display for GameType {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+impl fmt::Display for GameType {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             GameType::Daily(day) => write!(f, "{}", day),
             GameType::Custom => write!(f, "custom"),
