@@ -6,15 +6,14 @@ mod game;
 mod keyboard;
 mod letters;
 mod state;
+mod terminal;
 
 use args::{App, GameMode};
 use controller::GameController;
 use game::Game;
 use rand::Rng;
 
-fn main() -> color_eyre::Result<()> {
-    color_eyre::install()?;
-
+fn main() -> eyre::Result<()> {
     let app = App::parse();
     let game = match app.game_mode {
         None => Game::new()?,
